@@ -83,13 +83,14 @@ def registerGroup(Group, name, group=None, **kwargs):
     return Group.register(name, group)
 
 def registerGlobalValue(group, name, value):
-    value.channelValue = False
+    value._networkValue = False
+    value._channelValue = False
     return group.register(name, value)
 
-def registerChannelValue(group, name, value, opSettable=True):
+def registerNetworkValue(group, name, value):
     value._supplyDefault = True
-    value.channelValue = True
-    value._opSettable = opSettable
+    value._networkValue = True
+    value._channelValue = False
     g = group.register(name, value)
     gname = g._name.lower()
     for name in registry._cache.keys():
@@ -97,8 +98,30 @@ def registerChannelValue(group, name, value, opSettable=True):
             name = name[len(gname)+1:] # +1 for .
             parts = registry.split(name)
             if len(parts) == 1 and parts[0] and ircutils.isChannel(parts[0]):
-                # This gets the channel values so they always persist.
+                # This gets the network values so they always persist.
                 g.get(parts[0])()
+    return g
+
+def registerChannelValue(group, name, value, opSettable=True):
+    value._supplyDefault = True
+    value._networkValue = True
+    value._channelValue = True
+    value._opSettable = opSettable
+    g = group.register(name, value)
+    gname = g._name.lower()
+    for name in registry._cache.keys():
+        if name.lower().startswith(gname) and len(gname) < len(name):
+            name = name[len(gname)+1:] # +1 for .
+            parts = registry.split(name)
+            if len(parts) == 2 and parts[0] and parts[0].startswith(':') \
+                    and parts[1] and ircutils.isChannel(parts[1]):
+                # This gets the network+channel values so they always persist.
+                g.get(parts[0])()
+                g.get(parts[0]).get(parts[1])()
+            elif len(parts) == 1 and parts[0] and ircutils.isChannel(parts[0]):
+                # Old-style variant of the above, without a network
+                g.get(parts[0])()
+    return g
 
 def registerPlugin(name, currentValue=None, public=True):
     group = registerGlobalValue(supybot.plugins, name,
@@ -1128,7 +1151,7 @@ class Banmask(registry.SpaceSeparatedSetOfStrings):
                 self.error()
         self.__parent.setValue(self.List(v))
 
-    def makeBanmask(self, hostmask, options=None, channel=None):
+    def makeBanmask(self, hostmask, options=None, channel=None, network=None):
         """Create a banmask from the given hostmask.  If a style of banmask
         isn't specified via options, the value of
         conf.supybot.protocols.irc.banmask is used.
@@ -1138,13 +1161,15 @@ class Banmask(registry.SpaceSeparatedSetOfStrings):
         only the exact hostmask will be used."""
         if not channel:
             channel = dynamic.channel
-        assert channel is None or ircutils.isChannel(channel)
+        if not network:
+            network = dynamic.irc.network
         (nick, user, host) = ircutils.splitHostmask(hostmask)
         bnick = '*'
         buser = '*'
         bhost = '*'
         if not options:
-            options = get(supybot.protocols.irc.banmask, channel)
+            options = supybot.protocols.irc.banmask.getSpecific(
+                channel, network)()
         for option in options:
             if option == 'nick':
                 bnick = nick
