@@ -32,6 +32,7 @@ import copy
 import time
 import random
 import base64
+import textwrap
 import collections
 
 try:
@@ -49,6 +50,8 @@ from .utils.str import rsplit
 from .utils.iter import chain
 from .utils.structures import smallqueue, RingBuffer
 
+MAX_LINE_SIZE = 512 # Including \r\n
+
 ###
 # The base class for a callback to be registered with an Irc object.  Shows
 # the required interface for callbacks -- name(),
@@ -377,11 +380,15 @@ class IrcState(IrcCommandDispatcher, log.Firewalled):
     def reset(self):
         """Resets the state to normal, unconnected state."""
         self.history.reset()
+        self.history.resize(conf.supybot.protocols.irc.maxHistoryLength())
+        self.ircd = None
         self.channels.clear()
         self.supported.clear()
         self.nicksToHostmasks.clear()
-        self.history.resize(conf.supybot.protocols.irc.maxHistoryLength())
         self.batches = {}
+        self.capabilities_ack = set()
+        self.capabilities_nak = set()
+        self.capabilities_ls = {}
 
     def __reduce__(self):
         return (self.__class__, (self.history, self.supported,
@@ -849,7 +856,7 @@ class Irc(IrcCommandDispatcher, log.Firewalled):
                     log.debug('%s.outFilter returned None.', callback.name())
                     return self.takeMsg()
                 world.debugFlush()
-            if len(str(msg)) > 512:
+            if len(str(msg)) > MAX_LINE_SIZE:
                 # Yes, this violates the contract, but at this point it doesn't
                 # matter.  That's why we gotta go munging in private attributes
                 #
@@ -858,7 +865,7 @@ class Irc(IrcCommandDispatcher, log.Firewalled):
                 # this issue, there's no fundamental reason to make it a
                 # warning.
                 log.debug('Truncating %r, message is too long.', msg)
-                msg._str = msg._str[:500] + '\r\n'
+                msg._str = msg._str[:MAX_LINE_SIZE-2] + '\r\n'
                 msg._len = len(str(msg))
             # I don't think we should do this.  Why should it matter?  If it's
             # something important, then the server will send it back to us,
@@ -1218,7 +1225,8 @@ class Irc(IrcCommandDispatcher, log.Firewalled):
         self.endCapabilityNegociation()
 
     def do904(self, msg):
-        log.warning('%s: SASL authentication failed', self.network)
+        log.warning('%s: SASL authentication failed (mechanism: %s)',
+                self.network, self.sasl_current_mechanism)
         self.tryNextSaslMechanism()
 
     def do905(self, msg):
@@ -1294,19 +1302,24 @@ class Irc(IrcCommandDispatcher, log.Firewalled):
             self._addCapabilities(msg.args[3])
         elif len(msg.args) == 3: # End of LS
             self._addCapabilities(msg.args[2])
-            common_supported_capabilities = set(self.state.capabilities_ls) & \
-                    self.REQUEST_CAPABILITIES
+
             if 'sasl' in self.state.capabilities_ls:
                 s = self.state.capabilities_ls['sasl']
                 if s is not None:
                     self.filterSaslMechanisms(set(s.split(',')))
+
+            # Normally at this point, self.state.capabilities_ack should be
+            # empty; but let's just make sure we're not requesting the same
+            # caps twice for no reason.
+            new_caps = (
+                set(self.state.capabilities_ls) &
+                self.REQUEST_CAPABILITIES -
+                self.state.capabilities_ack)
             # NOTE: Capabilities are requested in alphabetic order, because
             # sets are unordered, and their "order" is nondeterministic.
             # This is needed for the tests.
-            if common_supported_capabilities:
-                caps = ' '.join(sorted(common_supported_capabilities))
-                self.sendMsg(ircmsgs.IrcMsg(command='CAP',
-                    args=('REQ', caps)))
+            if new_caps:
+                self._requestCaps(new_caps)
             else:
                 self.endCapabilityNegociation()
         else:
@@ -1347,9 +1360,15 @@ class Irc(IrcCommandDispatcher, log.Firewalled):
                 self.REQUEST_CAPABILITIES -
                 self.state.capabilities_ack)
         if common_supported_unrequested_capabilities:
-            caps = ' '.join(sorted(common_supported_unrequested_capabilities))
+            self._requestCaps(common_supported_unrequested_capabilities)
+
+    def _requestCaps(self, caps):
+        caps = ' '.join(sorted(caps))
+        # textwrap works here because in ASCII, all chars are 1 bytes:
+        cap_lines = textwrap.wrap(caps, MAX_LINE_SIZE-len('CAP REQ :'))
+        for cap_line in cap_lines:
             self.sendMsg(ircmsgs.IrcMsg(command='CAP',
-                args=('REQ', caps)))
+                args=('REQ', cap_line)))
 
     def monitor(self, targets):
         """Increment a counter of how many callbacks monitor each target;
