@@ -74,6 +74,24 @@ def cachingGetHelp(method, name=None, doc=None):
     return lastGetHelp
 callbacks.getHelp = cachingGetHelp
 
+real_time = time.time
+mock_time_offset = 0
+
+def mockTime():
+    """Wrapper for time.time() that adds an offset, eg. for skipping after a
+    timeout expired."""
+    return real_time() + mock_time_offset
+
+def timeFastForward(extra_offset):
+    global mock_time_offset
+    mock_time_offset += extra_offset
+
+def setupMockTime():
+    time.time = mockTime
+
+def teardownMockTime():
+    time.time = real_time
+
 def retry(tries=3):
     assert tries > 0
     def decorator(f):
@@ -96,8 +114,8 @@ def retry(tries=3):
         return newf
     return decorator
 
-def getTestIrc():
-    irc = irclib.Irc('test')
+def getTestIrc(name='test'):
+    irc = irclib.Irc(name)
     # Gotta clear the connect messages (USER, NICK, etc.)
     while irc.takeMsg():
         pass
@@ -133,11 +151,13 @@ class SupyTestCase(unittest.TestCase):
         log.critical('Beginning test case %s', self.id())
         threads = [t.getName() for t in threading.enumerate()]
         log.critical('Threads: %L', threads)
+        setupMockTime()
         unittest.TestCase.setUp(self)
 
     def tearDown(self):
         for irc in world.ircs[:]:
             irc._reallyDie()
+        teardownMockTime()
 
     if sys.version_info < (2, 7, 0):
         def assertIn(self, member, container, msg=None):
@@ -288,9 +308,9 @@ class PluginTestCase(SupyTestCase):
         if not expectException and self.myVerbose >= verbosity.EXCEPTIONS:
             conf.supybot.log.stdout.setValue(True)
         self.irc.feedMsg(msg)
-        fed = time.time()
+        fed = real_time()
         response = self.irc.takeMsg()
-        while response is None and time.time() - fed < timeout:
+        while response is None and real_time() - fed < timeout:
             time.sleep(0.01) # So it doesn't suck up 100% cpu.
             drivers.run()
             response = self.irc.takeMsg()
@@ -487,9 +507,9 @@ class ChannelPluginTestCase(PluginTestCase):
         if self.myVerbose >= verbosity.MESSAGES:
             print('Feeding: %r' % msg)
         self.irc.feedMsg(msg)
-        fed = time.time()
+        fed = real_time()
         response = self.irc.takeMsg()
-        while response is None and time.time() - fed < timeout:
+        while response is None and real_time() - fed < timeout:
             time.sleep(0.1)
             drivers.run()
             response = self.irc.takeMsg()
@@ -617,8 +637,6 @@ class FakeHTTPConnection(HTTPConnection):
         self.rfile = rfile
         self.wfile = wfile
     def send(self, data):
-        if minisix.PY3 and isinstance(data, bytes):
-            data = data.decode()
         self.wfile.write(data)
     #def putheader(self, name, value):
     #    self._headers[name] = value
@@ -633,14 +651,14 @@ class HTTPPluginTestCase(PluginTestCase):
 
     def request(self, url, method='GET', read=True, data={}):
         assert url.startswith('/')
-        wfile = minisix.io.StringIO()
-        rfile = minisix.io.StringIO()
+        wfile = minisix.io.BytesIO()
+        rfile = minisix.io.BytesIO()
         connection = FakeHTTPConnection(wfile, rfile)
         connection.putrequest(method, url)
         connection.endheaders()
         rfile.seek(0)
-        wfile.seek(0)
         handler = TestRequestHandler(rfile, wfile)
+        wfile.seek(0)
         if read:
             return (handler._response, wfile.read())
         else:
